package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmExamineRoleDetail;

/**
 * 时户数考核规则明细Service接口
 *
 * @author ruoyi
 * @date 2024-12-30
 */
public interface IPdmExamineRoleDetailService
{
    /**
     * 查询时户数考核规则明细
     *
     * @param id 时户数考核规则明细主键
     * @return 时户数考核规则明细
     */
    public PdmExamineRoleDetail selectPdmExamineRoleDetailById(Long id);

    /**
     * 查询时户数考核规则明细列表
     *
     * @param pdmExamineRoleDetail 时户数考核规则明细
     * @return 时户数考核规则明细集合
     */
    public List<PdmExamineRoleDetail> selectPdmExamineRoleDetailList(PdmExamineRoleDetail pdmExamineRoleDetail);

    /**
     * 新增时户数考核规则明细
     *
     * @param pdmExamineRoleDetail 时户数考核规则明细
     * @return 结果
     */
    public int insertPdmExamineRoleDetail(PdmExamineRoleDetail pdmExamineRoleDetail);

    /**
     * 修改时户数考核规则明细
     *
     * @param pdmExamineRoleDetail 时户数考核规则明细
     * @return 结果
     */
    public int updatePdmExamineRoleDetail(PdmExamineRoleDetail pdmExamineRoleDetail);

    /**
     * 批量删除时户数考核规则明细
     *
     * @param ids 需要删除的时户数考核规则明细主键集合
     * @return 结果
     */
    public int deletePdmExamineRoleDetailByIds(Long[] ids);

    /**
     * 删除时户数考核规则明细信息
     *
     * @param id 时户数考核规则明细主键
     * @return 结果
     */
    public int deletePdmExamineRoleDetailById(Long id);
}
